;;;;;;;;;;;;;;;;;;;;;;;;;;; -*- Mode: Emacs-Lisp -*- ;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; ffi-bbdb.el -- for printing BBDB net adresses.
;;; 
;;; Author          : Francois Felix Ingrand
;;; Created On      : Mon Feb  3 10:42:28 1997
;;; Last Modified By: Johan Vromans
;;; Last Modified On: Sat Apr 19 13:36:03 1997
;;; Update Count    : 23
;;; Status          : OK
;;
;;; This code is completely inspired by/stolen from bbdb-print.el code, which
;;; authors are:
;;;          Boris Goldowsky <boris@cs.rochester.edu>
;;;          Dirk Grunwald <grunwald@cs.colorado.edu>
;;;          Luigi Semenzato <luigi@paris.cs.berkeley.edu>
;;;
;;; Copyright (C) 1996 Felix Ingrand
;;;
;;; The Insidious Big Brother Database is free software; you can redistribute
;;; it and/or modify it under the terms of the GNU General Public License as
;;; published by the Free Software Foundation; either version 1, or (at your
;;; option) any later version.
;;;
;;; BBDB is distributed in the hope that it will be useful, but WITHOUT ANY
;;; WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
;;; FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
;;; details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Emacs; see the file COPYING.  If not, write to
;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.


;;; Install
;;; (autoload 'ffi-bbdb-write-email         "ffi-bbdb")
;;;
;;; (defadvice bbdb-save-db (after bbdb-save-db-write-email activate)
;;;  (ffi-bbdb-write-email))
;;;
;;; Here is an example of how to call it from batch
;;; emacs -batch -l $HOME/.emacs -l ffi-bbdb.el -f ffi-bbdb-write-email


;;; Code:

(require 'bbdb)
(require 'bbdb-com)

;;; Variables:

(defvar ffi-bbdb-write-email-file-name (concat bbdb-file ".email")
  "*Default file name for saving email info from BBDB .")

;;; Functions:

(defun ffi-bbdb-write-email ()
  (interactive)
  (let ((bbdb-write-email-file-name
	 (expand-file-name ffi-bbdb-write-email-file-name))
	(records (bbdb-records)))
    (find-file bbdb-write-email-file-name)
    (widen) (erase-buffer)
    (while records
      (ffi-bbdb-write-email-format-record (car records))
      (setq records (cdr records)))
    (goto-char (point-min))
    (save-buffer)
    (kill-buffer nil)
    )
  )

(defun ffi-bbdb-write-email-format-record (record)
  (bbdb-debug (if (bbdb-record-deleted-p record)
		  (error "plus ungood: email printing deleted record")))
      (let* ((net (and (bbdb-field-shown-p 'net)
		       (bbdb-record-net record))))
	(if net
	    (mapcar (lambda (x) (insert (format "%s\n" x)))
		    net))))

;;; ffi-bbdb.el ends here.


